@@ -3,7 +3,7 @@ import sys
 
 from .logger import OutflowLogger
 from .rotating_file_handler import RotatingFileHandlerPerUser
-from .terminal_color_formatter import TerminalColorFormatter
+from .formatter import OutflowFormatter
 from .socket_receiver import SocketReceiver
 from .stream_handler import StreamHandler
 
@@ -20,7 +20,7 @@ outflow_logger.__file__ = __file__
 
 # Map the submodules to the OutflowLogger instance properties to allow imports
 outflow_logger.RotatingFileHandlerPerUser = RotatingFileHandlerPerUser
-outflow_logger.TerminalColorFormatter = TerminalColorFormatter
+outflow_logger.OutflowFormatter = OutflowFormatter
 outflow_logger.LogRecordSocketReceiver = SocketReceiver
 outflow_logger.LogRecordStreamHandler = StreamHandler
 
