@@ -7,7 +7,6 @@ Read values from the file specified by the OUTFLOW_CONFIG_PATH environment varia
 
 import json
 import os
-
 from copy import deepcopy
 from pathlib import Path
 
@@ -15,9 +14,13 @@ import toml
 import yaml
 from outflow.core.generic.context_manager import ManagedClass
 from outflow.core.logging import default_config as default_logger_config
+from yamlinclude import YamlIncludeConstructor
 
 from .context_manager import PipelineContextManager
 
+YamlIncludeConstructor.add_to_loader_class(loader_class=yaml.SafeLoader)
+
+
 ENVIRONMENT_VARIABLE = "OUTFLOW_CONFIG_PATH"
 
 
@@ -64,7 +67,7 @@ class Config(ManagedClass, DictLikeMixin, context_manager=PipelineContextManager
 
         config_filepath = os.environ.get(ENVIRONMENT_VARIABLE)
         if not config_filepath:
-            if settings.ROOT_DIRECTORY is None:  # TODO try if settings file exists
+            if settings.ROOT_DIRECTORY is None:
                 config_filepath = None
             else:
                 # check for the default config file
@@ -85,6 +88,13 @@ class Config(ManagedClass, DictLikeMixin, context_manager=PipelineContextManager
         else:
             self.init_from_file(config_filepath_or_dict)
 
+    def resolve(self):
+        """
+        This method does nothing, it is useful to explicitly initialize the
+        lazy object from the pipeline.
+        """
+        pass
+
     def init_from_dict(self, config_dict):
         for key in config_dict:
             config_value = config_dict[key]
