@@ -7,16 +7,19 @@ import os
 import pathlib
 import socket
 import sys
-from pathlib import Path
 from hashlib import sha256
 from uuid import uuid4
 
-import cloudpickle
-
 from outflow import __version__ as outflow_version
+from outflow.core.exceptions import ExitPipeline
 from outflow.core.logging import logger, set_plugins_loggers_config
 from outflow.core.pipeline import config, context, settings
 from outflow.core.pipeline.context_manager import PipelineContextManager
+from outflow.core.pipeline.lazy_settings import DEFAULT_SETTINGS_MODULE
+from outflow.core.pipeline.lazy_settings import (
+    ENVIRONMENT_VARIABLE as SETTINGS_ENVIRONMENT_VARIABLE,
+)
+from outflow.core.pipeline.lazy_settings import Settings
 from outflow.core.plugin import Plugin
 from outflow.core.tasks.io_checker import IOChecker
 from outflow.core.workflow import WorkflowManager
@@ -67,22 +70,6 @@ class Pipeline:
                 "help": "Force backend",
             },
         ),
-        "map_uuid": (
-            ["--map-uuid", "-m"],
-            {
-                "help": "Launch outflow in remote run mode with the given map uuid",
-                "type": str,
-                "default": "",
-            },
-        ),
-        "run_uuid": (
-            ["--run-uuid", "-r"],
-            {
-                "help": "Specify the run ID",
-                "type": str,
-                "default": "",
-            },
-        ),
     }
 
     base_arguments = (
@@ -128,60 +115,58 @@ class Pipeline:
             sys.path.append(root_directory_abs_path)
 
         if settings_module is not None:
-            os.environ.setdefault("OUTFLOW_SETTINGS_MODULE", settings_module)
+            os.environ.setdefault(SETTINGS_ENVIRONMENT_VARIABLE, settings_module)
 
         # check pipeline level command line args
         self.system_args, self.command_argv = self.parse_system_args(argv=argv)
 
-        if self.system_args.map_uuid or self.system_args.run_uuid:
-            if (
-                self.system_args.map_uuid
-                and not self.system_args.run_uuid
-                or self.system_args.run_uuid
-                and not self.system_args.map_uuid
-            ):
-                raise Exception(
-                    "Arguments --map-uuid and --run-uuid must be used together"
+        if self.system_args.settings is not None:
+            os.environ[SETTINGS_ENVIRONMENT_VARIABLE] = self.system_args.settings
+
+        if self.system_args.config is not None:
+            os.environ["OUTFLOW_CONFIG_PATH"] = (
+                pathlib.Path(self.system_args.config).resolve().as_posix()
+            )
+
+        for dir_path in self.system_args.python_path:
+            sys.path.append(pathlib.Path(dir_path).resolve().as_posix())
+
+        # If true, show program's version number and exit.
+        self.display_version = self.system_args.version
+
+        # force the settings factory to use the module stored in the dedicated environment variable
+        settings.set_factory(
+            lambda: Settings.resolve_lazy_object(
+                settings_module=os.environ.get(
+                    SETTINGS_ENVIRONMENT_VARIABLE, DEFAULT_SETTINGS_MODULE
                 )
+            )
+        )
 
-            init_remote(self.system_args.map_uuid, self.system_args.run_uuid)
-        else:
+        settings.resolve()
+        config.resolve()
 
-            if self.system_args.settings is not None:
-                os.environ["OUTFLOW_SETTINGS_MODULE"] = self.system_args.settings
+        # setup the logger and force the verbose level if needed
+        if self.system_args.log_level is not None:
+            pipeline_config["logging"]["loggers"]["outflow"][
+                "level"
+            ] = self.system_args.log_level
 
-            if self.system_args.config is not None:
-                os.environ["OUTFLOW_CONFIG_PATH"] = (
-                    pathlib.Path(self.system_args.config).resolve().as_posix()
-                )
+        if self.system_args.no_color:
+            pipeline_config["logging"]["handlers"]["console"]["formatter"] = "simple"
 
-            for dir_path in self.system_args.python_path:
-                sys.path.append(pathlib.Path(dir_path).resolve().as_posix())
+        set_plugins_loggers_config()
 
-            # If true, show program's version number and exit.
-            self.display_version = self.system_args.version
+        logging.config.dictConfig(pipeline_config["logging"])
 
-            # setup the logger and force the verbose level if needed
-            if self.system_args.log_level is not None:
-                pipeline_config["logging"]["loggers"]["outflow"][
-                    "level"
-                ] = self.system_args.log_level
+        logger.debug(f"Config loaded: {pipeline_config}")
 
-            if self.system_args.no_color:
-                pipeline_config["logging"]["handlers"]["console"][
-                    "formatter"
-                ] = "simple"
+        if self.system_args.backend:
+            pipeline_config["backend"] = self.system_args.backend
 
-            set_plugins_loggers_config()
+        self.load_backends()
 
-            logging.config.dictConfig(pipeline_config["logging"])
-
-            logger.debug(f"Config loaded: {pipeline_config}")
-
-            if self.system_args.backend:
-                pipeline_config["backend"] = self.system_args.backend
-
-            self.load_backends()
+        context.resolve()
 
         self.load_plugins()
 
@@ -260,99 +245,82 @@ class Pipeline:
                 f"Could not find backend {backend_name}, "
                 "please check that it is correctly imported"
             )
-        return Backend()
+
+        backend = Backend()
+        context.backend_name = backend.name
+
+        return backend
 
     def run(self):
         """Run the pipeline"""
+        if self.display_version:
+            print(f"Outflow version '{outflow_version}'")
+            context.force_dry_run = True  # needed for _dispose() called from exit()
+            return 0
 
-        # remote run for slurm backend
-        if context.map_uuid and context.run_uuid:
+        context.force_dry_run = self.force_dry_run
 
-            run_dir = Path(f"outflow_{context.run_uuid}")
+        command = self.root_command.parse_command_tree(self.command_argv)
 
-            with open(
-                run_dir / f"map_info_{context.map_uuid}.pickle", "rb"
-            ) as map_info_file:
-                map_infos = cloudpickle.load(map_info_file)
+        # if no argument is supplied, the help message is triggered
+        # and command tree parser returns 0
+        if command == 0:
+            return command
 
-            task_id = int(os.environ["SLURM_ARRAY_TASK_ID"])
+        context.db_untracked = command.db_untracked
 
-            result = map_infos["run_workflow"](
-                map_infos["inner_workflow"][task_id],
-                map_infos["generated_inputs"][task_id],
-                task_id,
-                map_infos["raise_exceptions"],
-                map_infos["external_edges"],
+        backend_to_use = "default"
+        if self.system_args.backend:
+            backend_to_use = self.system_args.backend
+        elif command.backend:
+            backend_to_use = command.backend
+        elif config.get("backend", None):
+            backend_to_use = config["backend"]
+
+        backend = self.setup_backend(backend_to_use)
+
+        if command.db_untracked:
+            logger.debug(
+                "db_untracked=True passed to command init, this run will not be stored in the database"
             )
 
-            filename = f"map_result_{task_id}_{context.map_uuid}"
-            with open(run_dir / filename, "wb") as result_file:
-                cloudpickle.dump(result, result_file)
+        db_config = self.create_config_in_db()
+        db_run = self.create_run_in_db(db_config)
 
-        # regular run
-        else:
-            if self.display_version:
-                print(f"Outflow version '{outflow_version}'")
-                context.force_dry_run = True  # needed for _dispose() called from exit()
-                return 0
+        return_code = 1
 
-            context.force_dry_run = self.force_dry_run
+        try:
+            db_run.start()
+            db_run.hostname = socket.gethostname()
 
-            command = self.root_command.parse_command_tree(self.command_argv)
-
-            # if no argument is supplied, the help message is triggered
-            # and command tree parser returns 0
-            if command == 0:
-                return command
-
-            context.db_untracked = command.db_untracked
-
-            backend_to_use = "default"
-            if self.system_args.backend:
-                backend_to_use = self.system_args.backend
-            elif command.backend:
-                backend_to_use = command.backend
-            elif config.get("backend", None):
-                backend_to_use = config["backend"]
-
-            backend = self.setup_backend(backend_to_use)
-
-            context.backend_name = backend.name
-
-            if command.db_untracked:
-                logger.debug(
-                    "db_untracked=True passed to command init, this run will not be stored in the database"
+            with WorkflowManager() as top_level_workflow:
+                workflow = top_level_workflow.workflow
+                task_returning = command.setup_tasks()
+                IOChecker().compute(workflow)
+                self.result = backend.run(
+                    workflow=workflow, task_returning=task_returning
                 )
 
-            db_config = self.create_config_in_db()
-            db_run = self.create_run_in_db(db_config)
+            db_run.success()
+            return_code = 0
 
-            return_code = 1
+        except KeyboardInterrupt:
+            db_run.fail()
 
-            try:
-                db_run.start()
-                db_run.hostname = socket.gethostname()
+            # do not reraise KeyboardInterrupts
 
-                with WorkflowManager() as top_level_workflow:
-                    workflow = top_level_workflow.workflow
-                    task_returning = command.setup_tasks()
-                    IOChecker().compute(workflow)
-                    self.result = backend.run(
-                        workflow=workflow, task_returning=task_returning
-                    )
+        except ExitPipeline:
+            db_run.success()
 
-                db_run.success()
-                return_code = 0
+        except Exception:
+            db_run.fail()
+            # logger.print_exception() # TODO add this for file_handler but find a way to not duplicate exception in terminal
+            raise
 
-            except Exception:
-                db_run.fail()
+        finally:
+            backend.clean()
 
-                # logger.print_exception() # TODO add this for file_handler but find a way to not duplicate exception in terminal
-                raise
-            finally:
-                backend.clean()
-
-            return return_code
+        return return_code
 
     @staticmethod
     def create_config_in_db():
@@ -424,41 +392,8 @@ def get_pipeline_states():
 
 
 def set_pipeline_state(*, context_state, config_state, settings_state):
+    # force the factory to create an empty settings instance, will be overwritten during the settings set state
+    settings.set_factory(lambda: Settings.resolve_lazy_object(settings_module=None))
     context.setstate(context_state)
-    config.setstate(config_state)
     settings.setstate(settings_state)
-
-
-def init_remote(map_uuid, run_uuid):
-    PipelineContextManager().__enter__()
-
-    run_dir = Path(f"outflow_{run_uuid}")
-    with open(run_dir / "pipeline_states", "rb") as pipeline_states_file:
-        pipeline_states = cloudpickle.load(pipeline_states_file)
-
-    set_pipeline_state(**pipeline_states)
-
-    context.map_uuid = map_uuid
-    context.run_uuid = run_uuid
-
-    import logging.handlers
-
-    from outflow.core.logging import set_plugins_loggers_config
-
-    set_plugins_loggers_config()
-
-    logging.config.dictConfig(config["logging"])
-
-    socket_handler = logging.handlers.SocketHandler(
-        context.head_address, context.logger_port
-    )
-    socket_handler.setLevel(logging.DEBUG)
-    from outflow.core.logging.stream_handler import AddMessageSourceInfo
-
-    socket_handler.addFilter(AddMessageSourceInfo())
-
-    for logger_name in config["logging"].get("loggers", {}):
-        if logger_name == "":
-            continue
-        _logger = logging.getLogger(logger_name)
-        _logger.handlers = [socket_handler]
+    config.setstate(config_state)
