@@ -16,37 +16,6 @@ class PluginError(Exception):
     """
 
 
-def get_recursive_subclasses(cls: list) -> list:
-    subclasses = list()
-    for c in cls:
-        subclasses.append(c)
-        if c.__subclasses__():
-            subclasses.append(get_recursive_subclasses(c.__subclasses__()))
-
-    return subclasses
-
-
-# https://stackoverflow.com/questions/10823877/what-is-the-fastest-way-to-flatten-arbitrarily-nested-lists-in-python
-def flatten(iterable):
-    iterator, sentinel, stack = iter(iterable), object(), []
-    while True:
-        value = next(iterator, sentinel)
-        if value is sentinel:
-            if not stack:
-                break
-            iterator = stack.pop()
-        elif isinstance(value, str):
-            yield value
-        else:
-            try:
-                new_iterator = iter(value)
-            except TypeError:
-                yield value
-            else:
-                stack.append(iterator)
-                iterator = new_iterator
-
-
 class Plugin:
     """
     Class to manage plugins module of the pipeline.
