@@ -35,9 +35,14 @@ class Target:
 
                     class Visitor(ast.NodeVisitor):
                         def visit_Return(self, node: ast.Return):
-                            for output in node.value.keys:
-                                TaskClass.add_output(
-                                    cls(name=output.s, *args, **kwargs)
+                            try:
+                                for output in node.value.keys:
+                                    TaskClass.add_output(
+                                        cls(name=output.s, *args, **kwargs)
+                                    )
+                            except AttributeError:
+                                raise Exception(
+                                    f"Outflow could not automatically determine the outputs of task {TaskClass.name}"
                                 )
 
                     Visitor().visit(
