@@ -13,6 +13,8 @@ class Task(Model, Executable):
     Stores the tasks
     """
 
+    __tablename__ = "outflow_task"
+
     id = Column(Integer, primary_key=True, nullable=False)
     plugin = Column(String(256), nullable=True)
     name = Column(String(256), nullable=False)
@@ -23,12 +25,12 @@ class Task(Model, Executable):
     input_values = Column(JSON, nullable=True, server_default="{}")
     upstream_tasks = relationship(
         "Task",
-        secondary="edge",
+        secondary="outflow_edge",
         primaryjoin="Task.id == Edge.downstream_task_id",
         secondaryjoin="Task.id == Edge.upstream_task_id",
         backref="downstream_tasks",
     )
-    workflow_id = Column(Integer, ForeignKey("workflow.id"), nullable=False)
+    workflow_id = Column(Integer, ForeignKey("outflow_workflow.id"), nullable=False)
     workflow = relationship(
         "Workflow", back_populates="tasks", foreign_keys=[workflow_id]
     )
@@ -39,5 +41,7 @@ class Edge(Model):
     Stores relations between tasks
     """
 
+    __tablename__ = "outflow_edge"
+
     upstream_task_id = Column(Integer, ForeignKey(Task.id), primary_key=True)
     downstream_task_id = Column(Integer, ForeignKey(Task.id), primary_key=True)
