@@ -12,10 +12,14 @@ class Workflow(Model):
     Stores a workflow
     """
 
+    __tablename__ = "outflow_workflow"
+
     id = Column(Integer, primary_key=True)
     manager_task_id = Column(Integer, ForeignKey(Task.id), nullable=True)
     manager_task = relationship("Task", foreign_keys=[manager_task_id])
-    parent_workflow_id = Column(Integer, ForeignKey("workflow.id"), nullable=True)
+    parent_workflow_id = Column(
+        Integer, ForeignKey("outflow_workflow.id"), nullable=True
+    )
     parent_workflow = relationship("Workflow")
     run_id = Column(Integer, ForeignKey(Run.id), nullable=False)
 
