@@ -1,20 +1,28 @@
 # -*- coding: utf-8 -*-
 import re
+import signal
 import subprocess
 import sys
 import time
-from copy import deepcopy
-from pathlib import Path
 
 import cloudpickle
+from outflow.core.logging import logger
+from outflow.core.pipeline import context, settings
+from outflow.library.tasks.base_map_task import BaseMapTask, SigTerm
+from outflow.management.models.mixins import StateEnum
+from outflow.management.models.task import Task as TaskModel
+from outflow.management.models.workflow import Workflow
 from simple_slurm import Slurm
 
-from outflow.core.logging import logger
-from outflow.core.pipeline import context
-from outflow.library.tasks.base_map_task import BaseMapTask
-from outflow.management.models.mixins import StateEnum
-from outflow.management.models.workflow import Workflow
-from outflow.management.models.task import Task as TaskModel
+
+class SignalHandler:
+    term_received = False
+
+    def __init__(self):
+        signal.signal(signal.SIGTERM, self.handle_sigterm)
+
+    def handle_sigterm(self, *args):
+        self.term_received = True
 
 
 class SlurmMapTask(BaseMapTask):
@@ -43,21 +51,12 @@ class SlurmMapTask(BaseMapTask):
                 parent_task: child_task
                 for parent_task, child_task in self.external_edges.items()
             },
-            "inner_workflow": {
-                index: workflow
-                for index, workflow in enumerate(
-                    [
-                        deepcopy(self.inner_workflow) for i in range(len(inputs) - 1)
-                    ]  # copy n-1 times to keep the original
-                )
-            },
+            "inner_workflow": self.inner_workflow,
             "raise_exceptions": self.raise_exceptions,
             "run_workflow": self.run_workflow,
         }
 
-        map_info["inner_workflow"][len(inputs) - 1] = self.inner_workflow
-
-        run_dir = Path(f"outflow_{context.run_uuid}")
+        run_dir = settings.TEMP_DIR / f"outflow_{context.run_uuid}"
         with open(run_dir / f"map_info_{self.uuid}.pickle", "wb") as map_info_file:
             cloudpickle.dump(map_info, map_info_file)
 
@@ -72,17 +71,24 @@ class SlurmMapTask(BaseMapTask):
         if self.simultaneous_tasks:
             array_directive += f"%{self.simultaneous_tasks}"
 
+        slurm_out = settings.TEMP_DIR / "slurm_out"
+
+        slurm_out.mkdir(exist_ok=True)
+
         map_slurm_array = Slurm(
             array=array_directive,
             job_name=f"outflow_{self.name}_{self.uuid}",
+            error=(slurm_out / "slurm-%A_%a.err").as_posix(),
+            output=(slurm_out / "slurm-%A_%a.out").as_posix(),
             **self.sbatch_directives,
         )
 
         job_id = map_slurm_array.sbatch(
-            f"{sys.executable} manage.py --run-uuid {context.run_uuid} --map-uuid {self.uuid}",
+            f"srun {sys.executable} -m outflow.slurm.remote_runner --run-uuid {context.run_uuid} --map-uuid {self.uuid} --temp-dir {settings.TEMP_DIR.resolve()}",
+            verbose=False,
         )
 
-        context.job_ids_queue.put(job_id)
+        context.running_slurm_job_ids.append(job_id)
 
         results = list()
 
@@ -103,11 +109,16 @@ class SlurmMapTask(BaseMapTask):
 
         array_jobs = [f"{str(job_id)}_{i}" for i in range(nb_slurm_tasks)]
 
+        signal_handler = SignalHandler()
+
         while True:
             time.sleep(1)
             now = time.time()
             states = []
 
+            if signal_handler.term_received:
+                raise SigTerm()
+
             if now - start > timeout:
                 raise RuntimeError("timeout on slurm map")
 
@@ -120,14 +131,13 @@ class SlurmMapTask(BaseMapTask):
                         check=True,
                     ).stdout
                     state = re.findall(r"JobState=(\S*)", output)[0]
-                except subprocess.CalledProcessError:
-                    state = None
+
+                except Exception:
+                    state = "COMPLETED"
+
                 finally:
                     states.append(state)
 
-            if any([job is None for job in states]):
-                continue
-
             if all([state in slurm_end_states for state in states]):
                 break  # job array has ended
 
@@ -155,4 +165,6 @@ class SlurmMapTask(BaseMapTask):
             logger.error("One or more map output files could not be found")
             raise fe
 
+        context.running_slurm_job_ids.remove(job_id)
+
         return self.reduce(results)
